@@ -14,7 +14,7 @@ import hashlib
 
 from biomaj_core.utils import Utils
 from biomaj_download.downloadclient import DownloadClient
-from biomaj_download.message import message_pb2
+from biomaj_download.message import downmessage_pb2
 from biomaj_download.download.http import HTTPParse
 from biomaj_download.download.localcopy import LocalDownload
 
@@ -251,7 +251,8 @@ class Workflow(object):
         data_dir = self.session.config.get('data.dir')
         lock_dir = self.session.config.get('lock.dir', default=data_dir)
         lock_file = os.path.join(lock_dir, self.name + '.lock')
-        os.remove(lock_file)
+        if os.path.exists(lock_file):
+            os.remove(lock_file)
         return True
 
 
@@ -287,7 +288,12 @@ class RemoveWorkflow(Workflow):
             return False
 
         if os.path.exists(self.session.get_full_release_directory()):
-            shutil.rmtree(self.session.get_full_release_directory())
+            logging.info('Workflow:wf_remove:delete:' + self.session.get_full_release_directory())
+            try:
+                shutil.rmtree(self.session.get_full_release_directory())
+            except Exception:
+                logging.exception('Failed to delete bank release directory: ' + self.session.get_full_release_directory())
+                logging.error('Bank will be deleted but some files/dirs may still be present on system, you can safely manually delete them')
         return self.bank.remove_session(self.session.get('update_session_id'))
 
     def wf_removeprocess(self):
@@ -1082,6 +1088,7 @@ class UpdateWorkflow(Workflow):
             credentials = cf.get('server.credentials')
 
             remote_dir = cf.get('remote.dir')
+
             if protocol == 'directhttp' or protocol == 'directhttps' or protocol == 'directftp':
                 keys = cf.get('url.params')
                 if keys is not None:
@@ -1240,12 +1247,18 @@ class UpdateWorkflow(Workflow):
             keep_files = []
             nb_expected_files += len(downloader.files_to_download)
             if os.path.exists(offline_dir):
+                logging.debug('Workflow:wf_download:offline_check_dir:' + offline_dir)
                 for file_to_download in downloader.files_to_download:
                     # If file is in offline dir and has same date and size, do not download again
-                    if os.path.exists(offline_dir + '/' + file_to_download['name']):
+                    offline_file = file_to_download['name']
+                    if file_to_download.get('save_as', None):
+                        offline_file = file_to_download['save_as']
+                    logging.debug('Workflow:wf_download:offline_check_file:' + offline_file)
+                    if os.path.exists(offline_dir + '/' + offline_file):
+                        logging.debug('Workflow:wf_download:offline_check_file_identical:' + offline_file)
                         try:
-                            file_stat = os.stat(offline_dir + '/' + file_to_download['name'])
-                            f_stat = datetime.datetime.fromtimestamp(os.path.getmtime(offline_dir + '/' + file_to_download['name']))
+                            file_stat = os.stat(offline_dir + '/' + offline_file)
+                            f_stat = datetime.datetime.fromtimestamp(os.path.getmtime(offline_dir + '/' + offline_file))
                             year = str(f_stat.year)
                             month = str(f_stat.month)
                             day = str(f_stat.day)
@@ -1253,16 +1266,16 @@ class UpdateWorkflow(Workflow):
                                str(year) != str(file_to_download['year']) or \
                                str(month) != str(file_to_download['month']) or \
                                str(day) != str(file_to_download['day']):
-                                logging.debug('Workflow:wf_download:different_from_offline:' + file_to_download['name'])
+                                logging.debug('Workflow:wf_download:different_from_offline:' + offline_file)
                                 keep_files.append(file_to_download)
                             else:
-                                logging.debug('Workflow:wf_download:offline:' + file_to_download['name'])
+                                logging.debug('Workflow:wf_download:same_as_offline:' + offline_file)
                                 files_in_offline += 1
                                 copied_files.append(file_to_download)
                         except Exception as e:
                             # Could not get stats on file
                             logging.debug('Workflow:wf_download:offline:failed to stat file: ' + str(e))
-                            os.remove(offline_dir + '/' + file_to_download['name'])
+                            os.remove(offline_dir + '/' + offline_file)
                             keep_files.append(file_to_download)
                     else:
                         keep_files.append(file_to_download)
@@ -1352,15 +1365,15 @@ class UpdateWorkflow(Workflow):
 
         for downloader in downloaders:
             for file_to_download in downloader.files_to_download:
-                operation = message_pb2.Operation()
+                operation = downmessage_pb2.Operation()
                 operation.type = 1
-                message = message_pb2.DownloadFile()
+                message = downmessage_pb2.DownloadFile()
                 message.bank = self.name
                 message.session = session
                 message.local_dir = offline_dir
-                remote_file = message_pb2.DownloadFile.RemoteFile()
+                remote_file = downmessage_pb2.DownloadFile.RemoteFile()
                 protocol = downloader.protocol
-                remote_file.protocol = message_pb2.DownloadFile.Protocol.Value(protocol.upper())
+                remote_file.protocol = downmessage_pb2.DownloadFile.Protocol.Value(protocol.upper())
 
                 if downloader.credentials:
                     remote_file.credentials = downloader.credentials
@@ -1372,7 +1385,7 @@ class UpdateWorkflow(Workflow):
                     remote_file.remote_dir = ''
 
                 if http_parse:
-                    msg_http_parse = message_pb2.DownloadFile.HttpParse()
+                    msg_http_parse = downmessage_pb2.DownloadFile.HttpParse()
                     msg_http_parse.dir_line = http_parse.dir_line
                     msg_http_parse.file_line = http_parse.file_line
                     msg_http_parse.dir_name = http_parse.dir_name
@@ -1412,7 +1425,7 @@ class UpdateWorkflow(Workflow):
                 if 'md5' in file_to_download and file_to_download['md5']:
                     biomaj_file.metadata.md5 = file_to_download['md5']
 
-                message.http_method = message_pb2.DownloadFile.HTTP_METHOD.Value(downloader.method.upper())
+                message.http_method = downmessage_pb2.DownloadFile.HTTP_METHOD.Value(downloader.method.upper())
 
                 timeout_download = cf.get('timeout.download', default=None)
                 if timeout_download:
@@ -1422,7 +1435,7 @@ class UpdateWorkflow(Workflow):
                         logging.error('Wrong timeout type for timeout.download: ' + str(e))
 
                 if self.span:
-                    trace = message_pb2.Operation.Trace()
+                    trace = downmessage_pb2.Operation.Trace()
                     trace.trace_id = self.span.get_trace_id()
                     trace.span_id = self.span.get_span_id()
                     operation.trace.MergeFrom(trace)
